#============================================================================
#  Name:
#    $(TARGET).MAK
#
#  Description:
#    Makefile to build the $(TARGET) downloadable module.
#
#   The following nmake targets are available in this makefile:
#
#     all           - make .elf and .mod image files (default)
#     clean         - delete object directory and image files
#     filename.o    - make object file
#
#   The above targets can be made with the following command:
#
#     nmake /f $(TARGET).mak [target]
#
#  Assumptions:
#    1. The environment variable ADSHOME is set to the root directory of the
#       arm tools.
#    2. The version of ADS is 1.2 or above.
#
#  Notes:
#    None.
#
#
#        Copyright  2000-2001 QUALCOMM Incorporated.
#               All Rights Reserved.
#            QUALCOMM Proprietary/GTDR
#
#----------------------------------------------------------------------------
#============================================================================
ARM_HOME       =$(ARMHOME)
BREW_HOME      =$(BREWDIR)
TARGET         =LifeGameApp
OBJS           =LIFEGA~1.o BPPLib.o CHANGE~1.o LifeGame.o LIFEGA~2.o LIFEGA~3.o LIFEGA~4.o LIFBE3~1.o LOADPA~1.o MEMORY~1.o SAVEPA~1.o SOFTKE~1.o AEEAPP~1.o AEEMOD~1.o 
APP_INCLUDES   =-I $(BREWDIR)\inc 

#-------------------------------------------------------------------------------
# Target file name and type definitions
#-------------------------------------------------------------------------------

EXETYPE    = elf                # Target image file format
MODULE     = mod                # Downloadable module extension

#-------------------------------------------------------------------------------
# Target compile time symbol definitions
#
# Tells the SDK source stuffs that we're building a dynamic app.
#-------------------------------------------------------------------------------

DYNAPP          = -DDYNAMIC_APP


#-------------------------------------------------------------------------------
# Software tool and environment definitions
#-------------------------------------------------------------------------------

AEESRCPATH = $(BREW_HOME)\src
AEEINCPATH = $(BREW_HOME)\inc

ARMBIN = $(ARM_HOME)\bin        # ARM ADS application directory
ARMINC = $(ARM_HOME)\include    # ARM ADS include file directory
ARMLIB = $(ARM_HOME)\lib        # ARM ADS library directory

ARMCC    = $(ARMBIN)\armcc      # ARM ADS ARM 32-bit inst. set ANSI CPP compiler
ARMCPP   = $(ARMBIN)\armcpp     # ARM ADS ARM 32-bit inst. set ANSI CPP compiler
LD       = $(ARMBIN)\armlink     # ARM ADS linker
HEXTOOL  = $(ARMBIN)\fromelf     # ARM ADS utility to create hex file from image

OBJ_CMD    = -o                 # Command line option to specify output filename

#-------------------------------------------------------------------------------
# Processor architecture options
#-------------------------------------------------------------------------------

CPU = -cpu ARM7TDMI             # ARM7TDMI target processor

#-------------------------------------------------------------------------------
# ARM Procedure Call Standard (APCS) options
#-------------------------------------------------------------------------------

ROPI     = ropi                 # Read-Only(code) Position independence
INTERWRK = interwork            # Allow ARM-Thumb interworking

APCS = -apcs /$(ROPI)/$(INTERWRK)/norwpi

#-------------------------------------------------------------------------------
# Additional compile time error checking options
#-------------------------------------------------------------------------------

CHK = -fa                       # Check for data flow anomolies

#-------------------------------------------------------------------------------
# Compiler output options
#-------------------------------------------------------------------------------

OUT = -c                        # Object file output only

#-------------------------------------------------------------------------------
# Compiler/assembler debug options
#-------------------------------------------------------------------------------

DBG = -g                        # Enable debug

#-------------------------------------------------------------------------------
# Compiler optimization options
#-------------------------------------------------------------------------------

OPT = -Ospace -O2               # Full compiler optimization for space

#-------------------------------------------------------------------------------
# Compiler code generation options
#-------------------------------------------------------------------------------

END = -littleend                # Compile for little endian memory architecture
ZA  = -zo                       # LDR may only access 32-bit aligned addresses

CODE = $(END) $(ZA)


#-------------------------------------------------------------------------------
# Include file search path options
#-------------------------------------------------------------------------------

INC = -I. -I$(AEEINCPATH) $(APP_INCLUDES)


#-------------------------------------------------------------------------------
# Compiler pragma emulation options
#-------------------------------------------------------------------------------


#-------------------------------------------------------------------------------
# Linker options
#-------------------------------------------------------------------------------

LINK_CMD = -o                    #Command line option to specify output file
                                 #on linking

ROPILINK = -ropi                 #Link image as Read-Only Position Independent

LINK_ORDER = -first AEEMod_Load

#-------------------------------------------------------------------------------
# HEXTOOL options
#-------------------------------------------------------------------------------

BINFORMAT = -bin


#-------------------------------------------------------------------------------
# Compiler flag definitions
#-------------------------------------------------------------------------------

CFLAGS0 = $(OUT) $(DYNAPP) $(CPU) $(APCS) $(CODE) $(CHK) $(DBG)
CFLAGS  = $(CFLAGS0) $(OPT)

#-------------------------------------------------------------------------------
# Linker flag definitions
#-------------------------------------------------------------------------------

# the -entry flag is not really needed, but it keeps the linker from reporting
# warning L6305W (no entry point).  The address
LFLAGS = $(ROPILINK) -rwpi -entry AEEMod_Load


#----------------------------------------------------------------------------
# Default target
#----------------------------------------------------------------------------

all :  $(TARGET).$(MODULE)

#----------------------------------------------------------------------------
# Clean target
#----------------------------------------------------------------------------

# The object subdirectory, target image file, and target hex file are deleted.

clean :
        @echo ---------------------------------------------------------------
        @echo CLEAN
        -del /f $(OBJS)
        -del /f $(TARGET).$(EXETYPE)
        -del /f $(TARGET).$(MODULE)
        @echo ---------------------------------------------------------------

#============================================================================
#                           DEFAULT SUFFIX RULES
#============================================================================

# The following are the default suffix rules used to compile all objects that
# are not specifically included in one of the module specific rules defined
# in the next section.

# The following macros are used to specify the output object file, MSG_FILE
# symbol definition and input source file on the compile line in the rules
# defined below.

SRC_CPP_FILE = $(@F:.o=.cpp)      # Input source file specification
SRC_C_FILE   = $(@F:.o=.c)      # Input source file specification
OBJ_FILE = $(OBJ_CMD) $(@F)   # Output object file specification

.SUFFIXES :
.SUFFIXES : .o .dep .c .cpp

#--------------------------------------------------------------------------
# C code inference rules
#----------------------------------------------------------------------------

.cpp.o:
        @echo ---------------------------------------------------------------
        @echo OBJECT $(@F)
        $(ARMCPP) $(CFLAGS) $(INC) $(OBJ_FILE) $(SRC_CPP_FILE)
        @echo ---------------------------------------------------------------


{$(AEESRCPATH)}.c.o:
        @echo ---------------------------------------------------------------
        @echo OBJECT $(@F)
        $(ARMCC) $(CFLAGS) $(INC) $(OBJ_FILE) $(AEESRCPATH)\$(SRC_C_FILE)
        @echo ---------------------------------------------------------------


#===============================================================================
#                           MODULE SPECIFIC RULES
#===============================================================================

APP_OBJS =  $(OBJS)

#----------------------------------------------------------------------------
# Lib file targets
#----------------------------------------------------------------------------

$(TARGET).$(MODULE) : $(TARGET).$(EXETYPE)
        @echo ---------------------------------------------------------------
        @echo TARGET $@
        $(HEXTOOL)  $(TARGET).$(EXETYPE) $(BINFORMAT) $(TARGET).$(MODULE)

$(TARGET).$(EXETYPE) : $(APP_OBJS)
        @echo ---------------------------------------------------------------
        @echo TARGET $@
        $(LD) $(LINK_CMD) $(TARGET).$(EXETYPE) $(LFLAGS) $(APP_OBJS) $(LINK_ORDER)

#----------------------------------------------------------------------------
# Applet Specific Rules
#----------------------------------------------------------------------------


RULE1 = c:\LIFEGA~1
{$(RULE1)}.c.o:
	@echo ---------------------------------------------------------------
	@echo OBJECT $(@F)
	$(ARMCC) $(CFLAGS) $(INC) $(OBJ_FILE)  $(RULE1)\$(SRC_C_FILE)
	@echo ---------------------------------------------------------------


RULE2 = c:\PROGRA~1\BREWSD~1.1JA\src
{$(RULE2)}.c.o:
	@echo ---------------------------------------------------------------
	@echo OBJECT $(@F)
	$(ARMCC) $(CFLAGS) $(INC) $(OBJ_FILE)  $(RULE2)\$(SRC_C_FILE)
	@echo ---------------------------------------------------------------


# --------------------------------------------
# DEPENDENCY LIST, DO NOT EDIT BELOW THIS LINE
# --------------------------------------------


lifega~1.o:	c:\lifega~1\lifega~1.cpp
lifega~1.o:	c:\lifega~1\lifegameapp.hpp
lifega~1.o:	$(BREWDIR)\inc\aeemodgen.h
lifega~1.o:	$(BREWDIR)\inc\aee.h
lifega~1.o:	$(BREWDIR)\inc\aeeclassids.h
lifega~1.o:	$(BREWDIR)\inc\aeeerror.h
lifega~1.o:	$(BREWDIR)\inc\aeecomdef.h
lifega~1.o:	$(BREWDIR)\inc\aeeshell.h
lifega~1.o:	$(BREWDIR)\inc\aee.h
lifega~1.o:	$(BREWDIR)\inc\aeevcodes.h
lifega~1.o:	$(BREWDIR)\inc\aeedisp.h
lifega~1.o:	$(BREWDIR)\inc\aee.h
lifega~1.o:	$(BREWDIR)\inc\aeebitmap.h
lifega~1.o:	$(BREWDIR)\inc\aee.h
lifega~1.o:	$(BREWDIR)\inc\aeefont.h
lifega~1.o:	$(BREWDIR)\inc\aeebitmap.h
lifega~1.o:	$(BREWDIR)\inc\aeeimage.h
lifega~1.o:	$(BREWDIR)\inc\aee.h
lifega~1.o:	$(BREWDIR)\inc\aeesoundplayer.h
lifega~1.o:	$(BREWDIR)\inc\aee.h
lifega~1.o:	$(BREWDIR)\inc\aeesound.h
lifega~1.o:	$(BREWDIR)\inc\aee.h
lifega~1.o:	$(BREWDIR)\inc\aeecontrols_res.h
lifega~1.o:	$(BREWDIR)\inc\aeelngcode.h
lifega~1.o:	$(BREWDIR)\inc\aeeappgen.h
lifega~1.o:	$(BREWDIR)\inc\aee.h
lifega~1.o:	$(BREWDIR)\inc\aeeshell.h
lifega~1.o:	$(BREWDIR)\inc\aeemodgen.h
lifega~1.o:	$(BREWDIR)\inc\aeeshell.h
lifega~1.o:	$(BREWDIR)\inc\aeetext.h
lifega~1.o:	$(BREWDIR)\inc\aee.h
lifega~1.o:	$(BREWDIR)\inc\aeemenu.h
lifega~1.o:	$(BREWDIR)\inc\aee.h
lifega~1.o:	$(BREWDIR)\inc\aeeshell.h
lifega~1.o:	c:\lifega~1\lifegameapp.bid
lifega~1.o:	c:\lifega~1\softkeywindow.hpp
lifega~1.o:	c:\lifega~1\lifegameapp.hpp
lifega~1.o:	c:\lifega~1\bpplib.hpp
lifega~1.o:	$(BREWDIR)\inc\aeestdlib.h
lifega~1.o:	$(BREWDIR)\inc\aeecomdef.h
lifega~1.o:	$(BREWDIR)\inc\aee.h
lifega~1.o:	$(BREWDIR)\inc\aeeshell.h
lifega~1.o:	$(BREWDIR)\inc\aeegraphics.h
lifega~1.o:	$(BREWDIR)\inc\aee.h
lifega~1.o:	$(BREWDIR)\inc\aeedisp.h
lifega~1.o:	$(BREWDIR)\inc\aeebitmap.h
lifega~1.o:	c:\lifega~1\lifegamemainpanel.hpp
lifega~1.o:	c:\lifega~1\lifegameapp.hpp
lifega~1.o:	c:\lifega~1\softkeywindow.hpp
lifega~1.o:	c:\lifega~1\lifegame.hpp
lifega~1.o:	c:\lifega~1\bpplib.hpp
lifega~1.o:	c:\lifega~1\lifegameapp.hpp
lifega~1.o:	c:\lifega~1\lifegamemaincanvas.hpp
lifega~1.o:	c:\lifega~1\lifegame.hpp
lifega~1.o:	c:\lifega~1\lifegameapp.hpp
lifega~1.o:	c:\lifega~1\softkeywindow.hpp
lifega~1.o:	c:\lifega~1\lifegameeditcanvas.hpp
lifega~1.o:	c:\lifega~1\lifegame.hpp
lifega~1.o:	c:\lifega~1\lifegameapp.hpp
lifega~1.o:	c:\lifega~1\softkeywindow.hpp
lifega~1.o:	c:\lifega~1\savepanel.hpp
lifega~1.o:	c:\lifega~1\lifegame.hpp
lifega~1.o:	c:\lifega~1\memorypanel.hpp
lifega~1.o:	c:\lifega~1\lifegame.hpp
lifega~1.o:	c:\lifega~1\lifegamedata.hpp
lifega~1.o:	c:\lifega~1\bpplib.hpp
lifega~1.o:	c:\lifega~1\lifegame.hpp
lifega~1.o:	$(BREWDIR)\inc\aeefile.h
lifega~1.o:	$(BREWDIR)\inc\aee.h
lifega~1.o:	c:\lifega~1\softkeywindow.hpp
lifega~1.o:	c:\lifega~1\softkeywindow.hpp
lifega~1.o:	$(BREWDIR)\inc\aeetext.h
lifega~1.o:	c:\lifega~1\loadpanel.hpp
lifega~1.o:	c:\lifega~1\lifegame.hpp
lifega~1.o:	c:\lifega~1\memorypanel.hpp
lifega~1.o:	c:\lifega~1\changesizepanel.hpp
lifega~1.o:	c:\lifega~1\lifegame.hpp
lifega~1.o:	c:\lifega~1\softkeywindow.hpp
bpplib.o:	c:\lifega~1\bpplib.cpp
bpplib.o:	c:\lifega~1\bpplib.hpp
bpplib.o:	$(BREWDIR)\inc\aeestdlib.h
bpplib.o:	$(BREWDIR)\inc\aeecomdef.h
bpplib.o:	$(BREWDIR)\inc\aee.h
bpplib.o:	$(BREWDIR)\inc\aeeclassids.h
bpplib.o:	$(BREWDIR)\inc\aeeerror.h
bpplib.o:	$(BREWDIR)\inc\aeecomdef.h
bpplib.o:	$(BREWDIR)\inc\aeeshell.h
bpplib.o:	$(BREWDIR)\inc\aee.h
bpplib.o:	$(BREWDIR)\inc\aeevcodes.h
bpplib.o:	$(BREWDIR)\inc\aeedisp.h
bpplib.o:	$(BREWDIR)\inc\aee.h
bpplib.o:	$(BREWDIR)\inc\aeebitmap.h
bpplib.o:	$(BREWDIR)\inc\aee.h
bpplib.o:	$(BREWDIR)\inc\aeefont.h
bpplib.o:	$(BREWDIR)\inc\aeebitmap.h
bpplib.o:	$(BREWDIR)\inc\aeeimage.h
bpplib.o:	$(BREWDIR)\inc\aee.h
bpplib.o:	$(BREWDIR)\inc\aeesoundplayer.h
bpplib.o:	$(BREWDIR)\inc\aee.h
bpplib.o:	$(BREWDIR)\inc\aeesound.h
bpplib.o:	$(BREWDIR)\inc\aee.h
bpplib.o:	$(BREWDIR)\inc\aeecontrols_res.h
bpplib.o:	$(BREWDIR)\inc\aeelngcode.h
bpplib.o:	$(BREWDIR)\inc\aeegraphics.h
bpplib.o:	$(BREWDIR)\inc\aee.h
bpplib.o:	$(BREWDIR)\inc\aeedisp.h
bpplib.o:	$(BREWDIR)\inc\aeebitmap.h
change~1.o:	c:\lifega~1\change~1.cpp
change~1.o:	c:\lifega~1\changesizepanel.hpp
change~1.o:	c:\lifega~1\lifegame.hpp
change~1.o:	c:\lifega~1\bpplib.hpp
change~1.o:	$(BREWDIR)\inc\aeestdlib.h
change~1.o:	$(BREWDIR)\inc\aeecomdef.h
change~1.o:	$(BREWDIR)\inc\aee.h
change~1.o:	$(BREWDIR)\inc\aeeclassids.h
change~1.o:	$(BREWDIR)\inc\aeeerror.h
change~1.o:	$(BREWDIR)\inc\aeecomdef.h
change~1.o:	$(BREWDIR)\inc\aeeshell.h
change~1.o:	$(BREWDIR)\inc\aee.h
change~1.o:	$(BREWDIR)\inc\aeevcodes.h
change~1.o:	$(BREWDIR)\inc\aeedisp.h
change~1.o:	$(BREWDIR)\inc\aee.h
change~1.o:	$(BREWDIR)\inc\aeebitmap.h
change~1.o:	$(BREWDIR)\inc\aee.h
change~1.o:	$(BREWDIR)\inc\aeefont.h
change~1.o:	$(BREWDIR)\inc\aeebitmap.h
change~1.o:	$(BREWDIR)\inc\aeeimage.h
change~1.o:	$(BREWDIR)\inc\aee.h
change~1.o:	$(BREWDIR)\inc\aeesoundplayer.h
change~1.o:	$(BREWDIR)\inc\aee.h
change~1.o:	$(BREWDIR)\inc\aeesound.h
change~1.o:	$(BREWDIR)\inc\aee.h
change~1.o:	$(BREWDIR)\inc\aeecontrols_res.h
change~1.o:	$(BREWDIR)\inc\aeelngcode.h
change~1.o:	$(BREWDIR)\inc\aeegraphics.h
change~1.o:	$(BREWDIR)\inc\aee.h
change~1.o:	$(BREWDIR)\inc\aeedisp.h
change~1.o:	$(BREWDIR)\inc\aeebitmap.h
change~1.o:	c:\lifega~1\lifegameapp.hpp
change~1.o:	$(BREWDIR)\inc\aeemodgen.h
change~1.o:	$(BREWDIR)\inc\aee.h
change~1.o:	$(BREWDIR)\inc\aeeshell.h
change~1.o:	$(BREWDIR)\inc\aeeappgen.h
change~1.o:	$(BREWDIR)\inc\aee.h
change~1.o:	$(BREWDIR)\inc\aeeshell.h
change~1.o:	$(BREWDIR)\inc\aeemodgen.h
change~1.o:	$(BREWDIR)\inc\aeeshell.h
change~1.o:	$(BREWDIR)\inc\aeetext.h
change~1.o:	$(BREWDIR)\inc\aee.h
change~1.o:	$(BREWDIR)\inc\aeemenu.h
change~1.o:	$(BREWDIR)\inc\aee.h
change~1.o:	$(BREWDIR)\inc\aeeshell.h
change~1.o:	c:\lifega~1\lifegameapp.bid
change~1.o:	c:\lifega~1\softkeywindow.hpp
change~1.o:	c:\lifega~1\lifegameapp.hpp
change~1.o:	c:\lifega~1\bpplib.hpp
lifegame.o:	c:\lifega~1\lifegame.cpp
lifegame.o:	c:\lifega~1\lifegame.hpp
lifegame.o:	c:\lifega~1\bpplib.hpp
lifegame.o:	$(BREWDIR)\inc\aeestdlib.h
lifegame.o:	$(BREWDIR)\inc\aeecomdef.h
lifegame.o:	$(BREWDIR)\inc\aee.h
lifegame.o:	$(BREWDIR)\inc\aeeclassids.h
lifegame.o:	$(BREWDIR)\inc\aeeerror.h
lifegame.o:	$(BREWDIR)\inc\aeecomdef.h
lifegame.o:	$(BREWDIR)\inc\aeeshell.h
lifegame.o:	$(BREWDIR)\inc\aee.h
lifegame.o:	$(BREWDIR)\inc\aeevcodes.h
lifegame.o:	$(BREWDIR)\inc\aeedisp.h
lifegame.o:	$(BREWDIR)\inc\aee.h
lifegame.o:	$(BREWDIR)\inc\aeebitmap.h
lifegame.o:	$(BREWDIR)\inc\aee.h
lifegame.o:	$(BREWDIR)\inc\aeefont.h
lifegame.o:	$(BREWDIR)\inc\aeebitmap.h
lifegame.o:	$(BREWDIR)\inc\aeeimage.h
lifegame.o:	$(BREWDIR)\inc\aee.h
lifegame.o:	$(BREWDIR)\inc\aeesoundplayer.h
lifegame.o:	$(BREWDIR)\inc\aee.h
lifegame.o:	$(BREWDIR)\inc\aeesound.h
lifegame.o:	$(BREWDIR)\inc\aee.h
lifegame.o:	$(BREWDIR)\inc\aeecontrols_res.h
lifegame.o:	$(BREWDIR)\inc\aeelngcode.h
lifegame.o:	$(BREWDIR)\inc\aeegraphics.h
lifegame.o:	$(BREWDIR)\inc\aee.h
lifegame.o:	$(BREWDIR)\inc\aeedisp.h
lifegame.o:	$(BREWDIR)\inc\aeebitmap.h
lifegame.o:	c:\lifega~1\lifegameapp.hpp
lifegame.o:	$(BREWDIR)\inc\aeemodgen.h
lifegame.o:	$(BREWDIR)\inc\aee.h
lifegame.o:	$(BREWDIR)\inc\aeeshell.h
lifegame.o:	$(BREWDIR)\inc\aeeappgen.h
lifegame.o:	$(BREWDIR)\inc\aee.h
lifegame.o:	$(BREWDIR)\inc\aeeshell.h
lifegame.o:	$(BREWDIR)\inc\aeemodgen.h
lifegame.o:	$(BREWDIR)\inc\aeeshell.h
lifegame.o:	$(BREWDIR)\inc\aeetext.h
lifegame.o:	$(BREWDIR)\inc\aee.h
lifegame.o:	$(BREWDIR)\inc\aeemenu.h
lifegame.o:	$(BREWDIR)\inc\aee.h
lifegame.o:	$(BREWDIR)\inc\aeeshell.h
lifegame.o:	c:\lifega~1\lifegameapp.bid
lifegame.o:	c:\lifega~1\lifegameapp.hpp
lifega~2.o:	c:\lifega~1\lifega~2.cpp
lifega~2.o:	c:\lifega~1\lifegamedata.hpp
lifega~2.o:	c:\lifega~1\bpplib.hpp
lifega~2.o:	$(BREWDIR)\inc\aeestdlib.h
lifega~2.o:	$(BREWDIR)\inc\aeecomdef.h
lifega~2.o:	$(BREWDIR)\inc\aee.h
lifega~2.o:	$(BREWDIR)\inc\aeeclassids.h
lifega~2.o:	$(BREWDIR)\inc\aeeerror.h
lifega~2.o:	$(BREWDIR)\inc\aeecomdef.h
lifega~2.o:	$(BREWDIR)\inc\aeeshell.h
lifega~2.o:	$(BREWDIR)\inc\aee.h
lifega~2.o:	$(BREWDIR)\inc\aeevcodes.h
lifega~2.o:	$(BREWDIR)\inc\aeedisp.h
lifega~2.o:	$(BREWDIR)\inc\aee.h
lifega~2.o:	$(BREWDIR)\inc\aeebitmap.h
lifega~2.o:	$(BREWDIR)\inc\aee.h
lifega~2.o:	$(BREWDIR)\inc\aeefont.h
lifega~2.o:	$(BREWDIR)\inc\aeebitmap.h
lifega~2.o:	$(BREWDIR)\inc\aeeimage.h
lifega~2.o:	$(BREWDIR)\inc\aee.h
lifega~2.o:	$(BREWDIR)\inc\aeesoundplayer.h
lifega~2.o:	$(BREWDIR)\inc\aee.h
lifega~2.o:	$(BREWDIR)\inc\aeesound.h
lifega~2.o:	$(BREWDIR)\inc\aee.h
lifega~2.o:	$(BREWDIR)\inc\aeecontrols_res.h
lifega~2.o:	$(BREWDIR)\inc\aeelngcode.h
lifega~2.o:	$(BREWDIR)\inc\aeegraphics.h
lifega~2.o:	$(BREWDIR)\inc\aee.h
lifega~2.o:	$(BREWDIR)\inc\aeedisp.h
lifega~2.o:	$(BREWDIR)\inc\aeebitmap.h
lifega~2.o:	c:\lifega~1\lifegame.hpp
lifega~2.o:	c:\lifega~1\bpplib.hpp
lifega~2.o:	c:\lifega~1\lifegameapp.hpp
lifega~2.o:	$(BREWDIR)\inc\aeemodgen.h
lifega~2.o:	$(BREWDIR)\inc\aee.h
lifega~2.o:	$(BREWDIR)\inc\aeeshell.h
lifega~2.o:	$(BREWDIR)\inc\aeeappgen.h
lifega~2.o:	$(BREWDIR)\inc\aee.h
lifega~2.o:	$(BREWDIR)\inc\aeeshell.h
lifega~2.o:	$(BREWDIR)\inc\aeemodgen.h
lifega~2.o:	$(BREWDIR)\inc\aeeshell.h
lifega~2.o:	$(BREWDIR)\inc\aeetext.h
lifega~2.o:	$(BREWDIR)\inc\aee.h
lifega~2.o:	$(BREWDIR)\inc\aeemenu.h
lifega~2.o:	$(BREWDIR)\inc\aee.h
lifega~2.o:	$(BREWDIR)\inc\aeeshell.h
lifega~2.o:	c:\lifega~1\lifegameapp.bid
lifega~2.o:	$(BREWDIR)\inc\aeefile.h
lifega~2.o:	$(BREWDIR)\inc\aee.h
lifega~3.o:	c:\lifega~1\lifega~3.cpp
lifega~3.o:	c:\lifega~1\lifegameeditcanvas.hpp
lifega~3.o:	c:\lifega~1\lifegame.hpp
lifega~3.o:	c:\lifega~1\bpplib.hpp
lifega~3.o:	$(BREWDIR)\inc\aeestdlib.h
lifega~3.o:	$(BREWDIR)\inc\aeecomdef.h
lifega~3.o:	$(BREWDIR)\inc\aee.h
lifega~3.o:	$(BREWDIR)\inc\aeeclassids.h
lifega~3.o:	$(BREWDIR)\inc\aeeerror.h
lifega~3.o:	$(BREWDIR)\inc\aeecomdef.h
lifega~3.o:	$(BREWDIR)\inc\aeeshell.h
lifega~3.o:	$(BREWDIR)\inc\aee.h
lifega~3.o:	$(BREWDIR)\inc\aeevcodes.h
lifega~3.o:	$(BREWDIR)\inc\aeedisp.h
lifega~3.o:	$(BREWDIR)\inc\aee.h
lifega~3.o:	$(BREWDIR)\inc\aeebitmap.h
lifega~3.o:	$(BREWDIR)\inc\aee.h
lifega~3.o:	$(BREWDIR)\inc\aeefont.h
lifega~3.o:	$(BREWDIR)\inc\aeebitmap.h
lifega~3.o:	$(BREWDIR)\inc\aeeimage.h
lifega~3.o:	$(BREWDIR)\inc\aee.h
lifega~3.o:	$(BREWDIR)\inc\aeesoundplayer.h
lifega~3.o:	$(BREWDIR)\inc\aee.h
lifega~3.o:	$(BREWDIR)\inc\aeesound.h
lifega~3.o:	$(BREWDIR)\inc\aee.h
lifega~3.o:	$(BREWDIR)\inc\aeecontrols_res.h
lifega~3.o:	$(BREWDIR)\inc\aeelngcode.h
lifega~3.o:	$(BREWDIR)\inc\aeegraphics.h
lifega~3.o:	$(BREWDIR)\inc\aee.h
lifega~3.o:	$(BREWDIR)\inc\aeedisp.h
lifega~3.o:	$(BREWDIR)\inc\aeebitmap.h
lifega~3.o:	c:\lifega~1\lifegameapp.hpp
lifega~3.o:	$(BREWDIR)\inc\aeemodgen.h
lifega~3.o:	$(BREWDIR)\inc\aee.h
lifega~3.o:	$(BREWDIR)\inc\aeeshell.h
lifega~3.o:	$(BREWDIR)\inc\aeeappgen.h
lifega~3.o:	$(BREWDIR)\inc\aee.h
lifega~3.o:	$(BREWDIR)\inc\aeeshell.h
lifega~3.o:	$(BREWDIR)\inc\aeemodgen.h
lifega~3.o:	$(BREWDIR)\inc\aeeshell.h
lifega~3.o:	$(BREWDIR)\inc\aeetext.h
lifega~3.o:	$(BREWDIR)\inc\aee.h
lifega~3.o:	$(BREWDIR)\inc\aeemenu.h
lifega~3.o:	$(BREWDIR)\inc\aee.h
lifega~3.o:	$(BREWDIR)\inc\aeeshell.h
lifega~3.o:	c:\lifega~1\lifegameapp.bid
lifega~3.o:	c:\lifega~1\lifegameapp.hpp
lifega~3.o:	c:\lifega~1\softkeywindow.hpp
lifega~3.o:	c:\lifega~1\lifegameapp.hpp
lifega~3.o:	c:\lifega~1\bpplib.hpp
lifega~3.o:	c:\lifega~1\lifegameapp.hpp
lifega~3.o:	c:\lifega~1\bpplib.hpp
lifega~4.o:	c:\lifega~1\lifega~4.cpp
lifega~4.o:	c:\lifega~1\lifegamemaincanvas.hpp
lifega~4.o:	c:\lifega~1\lifegame.hpp
lifega~4.o:	c:\lifega~1\bpplib.hpp
lifega~4.o:	$(BREWDIR)\inc\aeestdlib.h
lifega~4.o:	$(BREWDIR)\inc\aeecomdef.h
lifega~4.o:	$(BREWDIR)\inc\aee.h
lifega~4.o:	$(BREWDIR)\inc\aeeclassids.h
lifega~4.o:	$(BREWDIR)\inc\aeeerror.h
lifega~4.o:	$(BREWDIR)\inc\aeecomdef.h
lifega~4.o:	$(BREWDIR)\inc\aeeshell.h
lifega~4.o:	$(BREWDIR)\inc\aee.h
lifega~4.o:	$(BREWDIR)\inc\aeevcodes.h
lifega~4.o:	$(BREWDIR)\inc\aeedisp.h
lifega~4.o:	$(BREWDIR)\inc\aee.h
lifega~4.o:	$(BREWDIR)\inc\aeebitmap.h
lifega~4.o:	$(BREWDIR)\inc\aee.h
lifega~4.o:	$(BREWDIR)\inc\aeefont.h
lifega~4.o:	$(BREWDIR)\inc\aeebitmap.h
lifega~4.o:	$(BREWDIR)\inc\aeeimage.h
lifega~4.o:	$(BREWDIR)\inc\aee.h
lifega~4.o:	$(BREWDIR)\inc\aeesoundplayer.h
lifega~4.o:	$(BREWDIR)\inc\aee.h
lifega~4.o:	$(BREWDIR)\inc\aeesound.h
lifega~4.o:	$(BREWDIR)\inc\aee.h
lifega~4.o:	$(BREWDIR)\inc\aeecontrols_res.h
lifega~4.o:	$(BREWDIR)\inc\aeelngcode.h
lifega~4.o:	$(BREWDIR)\inc\aeegraphics.h
lifega~4.o:	$(BREWDIR)\inc\aee.h
lifega~4.o:	$(BREWDIR)\inc\aeedisp.h
lifega~4.o:	$(BREWDIR)\inc\aeebitmap.h
lifega~4.o:	c:\lifega~1\lifegameapp.hpp
lifega~4.o:	$(BREWDIR)\inc\aeemodgen.h
lifega~4.o:	$(BREWDIR)\inc\aee.h
lifega~4.o:	$(BREWDIR)\inc\aeeshell.h
lifega~4.o:	$(BREWDIR)\inc\aeeappgen.h
lifega~4.o:	$(BREWDIR)\inc\aee.h
lifega~4.o:	$(BREWDIR)\inc\aeeshell.h
lifega~4.o:	$(BREWDIR)\inc\aeemodgen.h
lifega~4.o:	$(BREWDIR)\inc\aeeshell.h
lifega~4.o:	$(BREWDIR)\inc\aeetext.h
lifega~4.o:	$(BREWDIR)\inc\aee.h
lifega~4.o:	$(BREWDIR)\inc\aeemenu.h
lifega~4.o:	$(BREWDIR)\inc\aee.h
lifega~4.o:	$(BREWDIR)\inc\aeeshell.h
lifega~4.o:	c:\lifega~1\lifegameapp.bid
lifega~4.o:	c:\lifega~1\lifegameapp.hpp
lifega~4.o:	c:\lifega~1\softkeywindow.hpp
lifega~4.o:	c:\lifega~1\lifegameapp.hpp
lifega~4.o:	c:\lifega~1\bpplib.hpp
lifega~4.o:	c:\lifega~1\lifegameapp.hpp
lifega~4.o:	$(BREWDIR)\inc\aeegraphics.h
lifbe3~1.o:	c:\lifega~1\lifbe3~1.cpp
lifbe3~1.o:	c:\lifega~1\lifegamemainpanel.hpp
lifbe3~1.o:	c:\lifega~1\lifegameapp.hpp
lifbe3~1.o:	$(BREWDIR)\inc\aeemodgen.h
lifbe3~1.o:	$(BREWDIR)\inc\aee.h
lifbe3~1.o:	$(BREWDIR)\inc\aeeclassids.h
lifbe3~1.o:	$(BREWDIR)\inc\aeeerror.h
lifbe3~1.o:	$(BREWDIR)\inc\aeecomdef.h
lifbe3~1.o:	$(BREWDIR)\inc\aeeshell.h
lifbe3~1.o:	$(BREWDIR)\inc\aee.h
lifbe3~1.o:	$(BREWDIR)\inc\aeevcodes.h
lifbe3~1.o:	$(BREWDIR)\inc\aeedisp.h
lifbe3~1.o:	$(BREWDIR)\inc\aee.h
lifbe3~1.o:	$(BREWDIR)\inc\aeebitmap.h
lifbe3~1.o:	$(BREWDIR)\inc\aee.h
lifbe3~1.o:	$(BREWDIR)\inc\aeefont.h
lifbe3~1.o:	$(BREWDIR)\inc\aeebitmap.h
lifbe3~1.o:	$(BREWDIR)\inc\aeeimage.h
lifbe3~1.o:	$(BREWDIR)\inc\aee.h
lifbe3~1.o:	$(BREWDIR)\inc\aeesoundplayer.h
lifbe3~1.o:	$(BREWDIR)\inc\aee.h
lifbe3~1.o:	$(BREWDIR)\inc\aeesound.h
lifbe3~1.o:	$(BREWDIR)\inc\aee.h
lifbe3~1.o:	$(BREWDIR)\inc\aeecontrols_res.h
lifbe3~1.o:	$(BREWDIR)\inc\aeelngcode.h
lifbe3~1.o:	$(BREWDIR)\inc\aeeappgen.h
lifbe3~1.o:	$(BREWDIR)\inc\aee.h
lifbe3~1.o:	$(BREWDIR)\inc\aeeshell.h
lifbe3~1.o:	$(BREWDIR)\inc\aeemodgen.h
lifbe3~1.o:	$(BREWDIR)\inc\aeeshell.h
lifbe3~1.o:	$(BREWDIR)\inc\aeetext.h
lifbe3~1.o:	$(BREWDIR)\inc\aee.h
lifbe3~1.o:	$(BREWDIR)\inc\aeemenu.h
lifbe3~1.o:	$(BREWDIR)\inc\aee.h
lifbe3~1.o:	$(BREWDIR)\inc\aeeshell.h
lifbe3~1.o:	c:\lifega~1\lifegameapp.bid
lifbe3~1.o:	c:\lifega~1\softkeywindow.hpp
lifbe3~1.o:	c:\lifega~1\lifegameapp.hpp
lifbe3~1.o:	c:\lifega~1\bpplib.hpp
lifbe3~1.o:	$(BREWDIR)\inc\aeestdlib.h
lifbe3~1.o:	$(BREWDIR)\inc\aeecomdef.h
lifbe3~1.o:	$(BREWDIR)\inc\aee.h
lifbe3~1.o:	$(BREWDIR)\inc\aeeshell.h
lifbe3~1.o:	$(BREWDIR)\inc\aeegraphics.h
lifbe3~1.o:	$(BREWDIR)\inc\aee.h
lifbe3~1.o:	$(BREWDIR)\inc\aeedisp.h
lifbe3~1.o:	$(BREWDIR)\inc\aeebitmap.h
lifbe3~1.o:	$(BREWDIR)\inc\aeegraphics.h
lifbe3~1.o:	c:\lifega~1\bpplib.hpp
loadpa~1.o:	c:\lifega~1\loadpa~1.cpp
loadpa~1.o:	c:\lifega~1\loadpanel.hpp
loadpa~1.o:	c:\lifega~1\lifegame.hpp
loadpa~1.o:	c:\lifega~1\bpplib.hpp
loadpa~1.o:	$(BREWDIR)\inc\aeestdlib.h
loadpa~1.o:	$(BREWDIR)\inc\aeecomdef.h
loadpa~1.o:	$(BREWDIR)\inc\aee.h
loadpa~1.o:	$(BREWDIR)\inc\aeeclassids.h
loadpa~1.o:	$(BREWDIR)\inc\aeeerror.h
loadpa~1.o:	$(BREWDIR)\inc\aeecomdef.h
loadpa~1.o:	$(BREWDIR)\inc\aeeshell.h
loadpa~1.o:	$(BREWDIR)\inc\aee.h
loadpa~1.o:	$(BREWDIR)\inc\aeevcodes.h
loadpa~1.o:	$(BREWDIR)\inc\aeedisp.h
loadpa~1.o:	$(BREWDIR)\inc\aee.h
loadpa~1.o:	$(BREWDIR)\inc\aeebitmap.h
loadpa~1.o:	$(BREWDIR)\inc\aee.h
loadpa~1.o:	$(BREWDIR)\inc\aeefont.h
loadpa~1.o:	$(BREWDIR)\inc\aeebitmap.h
loadpa~1.o:	$(BREWDIR)\inc\aeeimage.h
loadpa~1.o:	$(BREWDIR)\inc\aee.h
loadpa~1.o:	$(BREWDIR)\inc\aeesoundplayer.h
loadpa~1.o:	$(BREWDIR)\inc\aee.h
loadpa~1.o:	$(BREWDIR)\inc\aeesound.h
loadpa~1.o:	$(BREWDIR)\inc\aee.h
loadpa~1.o:	$(BREWDIR)\inc\aeecontrols_res.h
loadpa~1.o:	$(BREWDIR)\inc\aeelngcode.h
loadpa~1.o:	$(BREWDIR)\inc\aeegraphics.h
loadpa~1.o:	$(BREWDIR)\inc\aee.h
loadpa~1.o:	$(BREWDIR)\inc\aeedisp.h
loadpa~1.o:	$(BREWDIR)\inc\aeebitmap.h
loadpa~1.o:	c:\lifega~1\lifegameapp.hpp
loadpa~1.o:	$(BREWDIR)\inc\aeemodgen.h
loadpa~1.o:	$(BREWDIR)\inc\aee.h
loadpa~1.o:	$(BREWDIR)\inc\aeeshell.h
loadpa~1.o:	$(BREWDIR)\inc\aeeappgen.h
loadpa~1.o:	$(BREWDIR)\inc\aee.h
loadpa~1.o:	$(BREWDIR)\inc\aeeshell.h
loadpa~1.o:	$(BREWDIR)\inc\aeemodgen.h
loadpa~1.o:	$(BREWDIR)\inc\aeeshell.h
loadpa~1.o:	$(BREWDIR)\inc\aeetext.h
loadpa~1.o:	$(BREWDIR)\inc\aee.h
loadpa~1.o:	$(BREWDIR)\inc\aeemenu.h
loadpa~1.o:	$(BREWDIR)\inc\aee.h
loadpa~1.o:	$(BREWDIR)\inc\aeeshell.h
loadpa~1.o:	c:\lifega~1\lifegameapp.bid
loadpa~1.o:	c:\lifega~1\memorypanel.hpp
loadpa~1.o:	c:\lifega~1\lifegame.hpp
loadpa~1.o:	c:\lifega~1\lifegamedata.hpp
loadpa~1.o:	c:\lifega~1\bpplib.hpp
loadpa~1.o:	c:\lifega~1\lifegame.hpp
loadpa~1.o:	$(BREWDIR)\inc\aeefile.h
loadpa~1.o:	$(BREWDIR)\inc\aee.h
loadpa~1.o:	c:\lifega~1\softkeywindow.hpp
loadpa~1.o:	c:\lifega~1\lifegameapp.hpp
loadpa~1.o:	c:\lifega~1\bpplib.hpp
memory~1.o:	c:\lifega~1\memory~1.cpp
memory~1.o:	c:\lifega~1\memorypanel.hpp
memory~1.o:	c:\lifega~1\lifegame.hpp
memory~1.o:	c:\lifega~1\bpplib.hpp
memory~1.o:	$(BREWDIR)\inc\aeestdlib.h
memory~1.o:	$(BREWDIR)\inc\aeecomdef.h
memory~1.o:	$(BREWDIR)\inc\aee.h
memory~1.o:	$(BREWDIR)\inc\aeeclassids.h
memory~1.o:	$(BREWDIR)\inc\aeeerror.h
memory~1.o:	$(BREWDIR)\inc\aeecomdef.h
memory~1.o:	$(BREWDIR)\inc\aeeshell.h
memory~1.o:	$(BREWDIR)\inc\aee.h
memory~1.o:	$(BREWDIR)\inc\aeevcodes.h
memory~1.o:	$(BREWDIR)\inc\aeedisp.h
memory~1.o:	$(BREWDIR)\inc\aee.h
memory~1.o:	$(BREWDIR)\inc\aeebitmap.h
memory~1.o:	$(BREWDIR)\inc\aee.h
memory~1.o:	$(BREWDIR)\inc\aeefont.h
memory~1.o:	$(BREWDIR)\inc\aeebitmap.h
memory~1.o:	$(BREWDIR)\inc\aeeimage.h
memory~1.o:	$(BREWDIR)\inc\aee.h
memory~1.o:	$(BREWDIR)\inc\aeesoundplayer.h
memory~1.o:	$(BREWDIR)\inc\aee.h
memory~1.o:	$(BREWDIR)\inc\aeesound.h
memory~1.o:	$(BREWDIR)\inc\aee.h
memory~1.o:	$(BREWDIR)\inc\aeecontrols_res.h
memory~1.o:	$(BREWDIR)\inc\aeelngcode.h
memory~1.o:	$(BREWDIR)\inc\aeegraphics.h
memory~1.o:	$(BREWDIR)\inc\aee.h
memory~1.o:	$(BREWDIR)\inc\aeedisp.h
memory~1.o:	$(BREWDIR)\inc\aeebitmap.h
memory~1.o:	c:\lifega~1\lifegameapp.hpp
memory~1.o:	$(BREWDIR)\inc\aeemodgen.h
memory~1.o:	$(BREWDIR)\inc\aee.h
memory~1.o:	$(BREWDIR)\inc\aeeshell.h
memory~1.o:	$(BREWDIR)\inc\aeeappgen.h
memory~1.o:	$(BREWDIR)\inc\aee.h
memory~1.o:	$(BREWDIR)\inc\aeeshell.h
memory~1.o:	$(BREWDIR)\inc\aeemodgen.h
memory~1.o:	$(BREWDIR)\inc\aeeshell.h
memory~1.o:	$(BREWDIR)\inc\aeetext.h
memory~1.o:	$(BREWDIR)\inc\aee.h
memory~1.o:	$(BREWDIR)\inc\aeemenu.h
memory~1.o:	$(BREWDIR)\inc\aee.h
memory~1.o:	$(BREWDIR)\inc\aeeshell.h
memory~1.o:	c:\lifega~1\lifegameapp.bid
memory~1.o:	c:\lifega~1\lifegamedata.hpp
memory~1.o:	c:\lifega~1\bpplib.hpp
memory~1.o:	c:\lifega~1\lifegame.hpp
memory~1.o:	$(BREWDIR)\inc\aeefile.h
memory~1.o:	$(BREWDIR)\inc\aee.h
memory~1.o:	c:\lifega~1\softkeywindow.hpp
memory~1.o:	c:\lifega~1\lifegameapp.hpp
memory~1.o:	c:\lifega~1\bpplib.hpp
savepa~1.o:	c:\lifega~1\savepa~1.cpp
savepa~1.o:	c:\lifega~1\savepanel.hpp
savepa~1.o:	c:\lifega~1\lifegame.hpp
savepa~1.o:	c:\lifega~1\bpplib.hpp
savepa~1.o:	$(BREWDIR)\inc\aeestdlib.h
savepa~1.o:	$(BREWDIR)\inc\aeecomdef.h
savepa~1.o:	$(BREWDIR)\inc\aee.h
savepa~1.o:	$(BREWDIR)\inc\aeeclassids.h
savepa~1.o:	$(BREWDIR)\inc\aeeerror.h
savepa~1.o:	$(BREWDIR)\inc\aeecomdef.h
savepa~1.o:	$(BREWDIR)\inc\aeeshell.h
savepa~1.o:	$(BREWDIR)\inc\aee.h
savepa~1.o:	$(BREWDIR)\inc\aeevcodes.h
savepa~1.o:	$(BREWDIR)\inc\aeedisp.h
savepa~1.o:	$(BREWDIR)\inc\aee.h
savepa~1.o:	$(BREWDIR)\inc\aeebitmap.h
savepa~1.o:	$(BREWDIR)\inc\aee.h
savepa~1.o:	$(BREWDIR)\inc\aeefont.h
savepa~1.o:	$(BREWDIR)\inc\aeebitmap.h
savepa~1.o:	$(BREWDIR)\inc\aeeimage.h
savepa~1.o:	$(BREWDIR)\inc\aee.h
savepa~1.o:	$(BREWDIR)\inc\aeesoundplayer.h
savepa~1.o:	$(BREWDIR)\inc\aee.h
savepa~1.o:	$(BREWDIR)\inc\aeesound.h
savepa~1.o:	$(BREWDIR)\inc\aee.h
savepa~1.o:	$(BREWDIR)\inc\aeecontrols_res.h
savepa~1.o:	$(BREWDIR)\inc\aeelngcode.h
savepa~1.o:	$(BREWDIR)\inc\aeegraphics.h
savepa~1.o:	$(BREWDIR)\inc\aee.h
savepa~1.o:	$(BREWDIR)\inc\aeedisp.h
savepa~1.o:	$(BREWDIR)\inc\aeebitmap.h
savepa~1.o:	c:\lifega~1\lifegameapp.hpp
savepa~1.o:	$(BREWDIR)\inc\aeemodgen.h
savepa~1.o:	$(BREWDIR)\inc\aee.h
savepa~1.o:	$(BREWDIR)\inc\aeeshell.h
savepa~1.o:	$(BREWDIR)\inc\aeeappgen.h
savepa~1.o:	$(BREWDIR)\inc\aee.h
savepa~1.o:	$(BREWDIR)\inc\aeeshell.h
savepa~1.o:	$(BREWDIR)\inc\aeemodgen.h
savepa~1.o:	$(BREWDIR)\inc\aeeshell.h
savepa~1.o:	$(BREWDIR)\inc\aeetext.h
savepa~1.o:	$(BREWDIR)\inc\aee.h
savepa~1.o:	$(BREWDIR)\inc\aeemenu.h
savepa~1.o:	$(BREWDIR)\inc\aee.h
savepa~1.o:	$(BREWDIR)\inc\aeeshell.h
savepa~1.o:	c:\lifega~1\lifegameapp.bid
savepa~1.o:	c:\lifega~1\memorypanel.hpp
savepa~1.o:	c:\lifega~1\lifegame.hpp
savepa~1.o:	c:\lifega~1\lifegamedata.hpp
savepa~1.o:	c:\lifega~1\bpplib.hpp
savepa~1.o:	c:\lifega~1\lifegame.hpp
savepa~1.o:	$(BREWDIR)\inc\aeefile.h
savepa~1.o:	$(BREWDIR)\inc\aee.h
savepa~1.o:	c:\lifega~1\softkeywindow.hpp
savepa~1.o:	c:\lifega~1\lifegameapp.hpp
savepa~1.o:	c:\lifega~1\bpplib.hpp
savepa~1.o:	c:\lifega~1\softkeywindow.hpp
savepa~1.o:	$(BREWDIR)\inc\aeetext.h
savepa~1.o:	c:\lifega~1\bpplib.hpp
softke~1.o:	c:\lifega~1\softke~1.cpp
softke~1.o:	c:\lifega~1\softkeywindow.hpp
softke~1.o:	c:\lifega~1\lifegameapp.hpp
softke~1.o:	$(BREWDIR)\inc\aeemodgen.h
softke~1.o:	$(BREWDIR)\inc\aee.h
softke~1.o:	$(BREWDIR)\inc\aeeclassids.h
softke~1.o:	$(BREWDIR)\inc\aeeerror.h
softke~1.o:	$(BREWDIR)\inc\aeecomdef.h
softke~1.o:	$(BREWDIR)\inc\aeeshell.h
softke~1.o:	$(BREWDIR)\inc\aee.h
softke~1.o:	$(BREWDIR)\inc\aeevcodes.h
softke~1.o:	$(BREWDIR)\inc\aeedisp.h
softke~1.o:	$(BREWDIR)\inc\aee.h
softke~1.o:	$(BREWDIR)\inc\aeebitmap.h
softke~1.o:	$(BREWDIR)\inc\aee.h
softke~1.o:	$(BREWDIR)\inc\aeefont.h
softke~1.o:	$(BREWDIR)\inc\aeebitmap.h
softke~1.o:	$(BREWDIR)\inc\aeeimage.h
softke~1.o:	$(BREWDIR)\inc\aee.h
softke~1.o:	$(BREWDIR)\inc\aeesoundplayer.h
softke~1.o:	$(BREWDIR)\inc\aee.h
softke~1.o:	$(BREWDIR)\inc\aeesound.h
softke~1.o:	$(BREWDIR)\inc\aee.h
softke~1.o:	$(BREWDIR)\inc\aeecontrols_res.h
softke~1.o:	$(BREWDIR)\inc\aeelngcode.h
softke~1.o:	$(BREWDIR)\inc\aeeappgen.h
softke~1.o:	$(BREWDIR)\inc\aee.h
softke~1.o:	$(BREWDIR)\inc\aeeshell.h
softke~1.o:	$(BREWDIR)\inc\aeemodgen.h
softke~1.o:	$(BREWDIR)\inc\aeeshell.h
softke~1.o:	$(BREWDIR)\inc\aeetext.h
softke~1.o:	$(BREWDIR)\inc\aee.h
softke~1.o:	$(BREWDIR)\inc\aeemenu.h
softke~1.o:	$(BREWDIR)\inc\aee.h
softke~1.o:	$(BREWDIR)\inc\aeeshell.h
softke~1.o:	c:\lifega~1\lifegameapp.bid
softke~1.o:	c:\lifega~1\bpplib.hpp
softke~1.o:	$(BREWDIR)\inc\aeestdlib.h
softke~1.o:	$(BREWDIR)\inc\aeecomdef.h
softke~1.o:	$(BREWDIR)\inc\aee.h
softke~1.o:	$(BREWDIR)\inc\aeeshell.h
softke~1.o:	$(BREWDIR)\inc\aeegraphics.h
softke~1.o:	$(BREWDIR)\inc\aee.h
softke~1.o:	$(BREWDIR)\inc\aeedisp.h
softke~1.o:	$(BREWDIR)\inc\aeebitmap.h
aeeapp~1.o:	$(BREWDIR)\src\aeeapp~1.c
aeeapp~1.o:	$(BREWDIR)\inc\aee.h
aeeapp~1.o:	$(BREWDIR)\inc\aeeclassids.h
aeeapp~1.o:	$(BREWDIR)\inc\aeeerror.h
aeeapp~1.o:	$(BREWDIR)\inc\aeecomdef.h
aeeapp~1.o:	$(BREWDIR)\inc\aeeshell.h
aeeapp~1.o:	$(BREWDIR)\inc\aee.h
aeeapp~1.o:	$(BREWDIR)\inc\aeevcodes.h
aeeapp~1.o:	$(BREWDIR)\inc\aeedisp.h
aeeapp~1.o:	$(BREWDIR)\inc\aee.h
aeeapp~1.o:	$(BREWDIR)\inc\aeebitmap.h
aeeapp~1.o:	$(BREWDIR)\inc\aee.h
aeeapp~1.o:	$(BREWDIR)\inc\aeefont.h
aeeapp~1.o:	$(BREWDIR)\inc\aeebitmap.h
aeeapp~1.o:	$(BREWDIR)\inc\aeeimage.h
aeeapp~1.o:	$(BREWDIR)\inc\aee.h
aeeapp~1.o:	$(BREWDIR)\inc\aeesoundplayer.h
aeeapp~1.o:	$(BREWDIR)\inc\aee.h
aeeapp~1.o:	$(BREWDIR)\inc\aeesound.h
aeeapp~1.o:	$(BREWDIR)\inc\aee.h
aeeapp~1.o:	$(BREWDIR)\inc\aeecontrols_res.h
aeeapp~1.o:	$(BREWDIR)\inc\aeelngcode.h
aeeapp~1.o:	$(BREWDIR)\inc\aeestdlib.h
aeeapp~1.o:	$(BREWDIR)\inc\aeecomdef.h
aeeapp~1.o:	$(BREWDIR)\inc\aee.h
aeeapp~1.o:	$(BREWDIR)\inc\aeeshell.h
aeeapp~1.o:	$(BREWDIR)\inc\aeeappgen.h
aeeapp~1.o:	$(BREWDIR)\inc\aee.h
aeeapp~1.o:	$(BREWDIR)\inc\aeeshell.h
aeeapp~1.o:	$(BREWDIR)\inc\aeemodgen.h
aeeapp~1.o:	$(BREWDIR)\inc\aee.h
aeeapp~1.o:	$(BREWDIR)\inc\aeeshell.h
aeeapp~1.o:	$(BREWDIR)\inc\aeemodgen.h
aeemod~1.o:	$(BREWDIR)\src\aeemod~1.c
aeemod~1.o:	$(BREWDIR)\inc\aeeheap.h
aeemod~1.o:	$(BREWDIR)\inc\aee.h
aeemod~1.o:	$(BREWDIR)\inc\aeeclassids.h
aeemod~1.o:	$(BREWDIR)\inc\aeeerror.h
aeemod~1.o:	$(BREWDIR)\inc\aeecomdef.h
aeemod~1.o:	$(BREWDIR)\inc\aeestdlib.h
aeemod~1.o:	$(BREWDIR)\inc\aeecomdef.h
aeemod~1.o:	$(BREWDIR)\inc\aee.h
aeemod~1.o:	$(BREWDIR)\inc\aeeshell.h
aeemod~1.o:	$(BREWDIR)\inc\aee.h
aeemod~1.o:	$(BREWDIR)\inc\aeevcodes.h
aeemod~1.o:	$(BREWDIR)\inc\aeedisp.h
aeemod~1.o:	$(BREWDIR)\inc\aee.h
aeemod~1.o:	$(BREWDIR)\inc\aeebitmap.h
aeemod~1.o:	$(BREWDIR)\inc\aee.h
aeemod~1.o:	$(BREWDIR)\inc\aeefont.h
aeemod~1.o:	$(BREWDIR)\inc\aeebitmap.h
aeemod~1.o:	$(BREWDIR)\inc\aeeimage.h
aeemod~1.o:	$(BREWDIR)\inc\aee.h
aeemod~1.o:	$(BREWDIR)\inc\aeesoundplayer.h
aeemod~1.o:	$(BREWDIR)\inc\aee.h
aeemod~1.o:	$(BREWDIR)\inc\aeesound.h
aeemod~1.o:	$(BREWDIR)\inc\aee.h
aeemod~1.o:	$(BREWDIR)\inc\aeecontrols_res.h
aeemod~1.o:	$(BREWDIR)\inc\aeelngcode.h
aeemod~1.o:	$(BREWDIR)\inc\aeestdlib.h
aeemod~1.o:	$(BREWDIR)\inc\aeemodgen.h
aeemod~1.o:	$(BREWDIR)\inc\aee.h
aeemod~1.o:	$(BREWDIR)\inc\aeeshell.h
aeemod~1.o:	$(BREWDIR)\inc\aeeappgen.h
aeemod~1.o:	$(BREWDIR)\inc\aee.h
aeemod~1.o:	$(BREWDIR)\inc\aeeshell.h
aeemod~1.o:	$(BREWDIR)\inc\aeemodgen.h
