#include "MemoryPanel.hpp"

ListBox::ListBox(WindowManager* wm_, int x_, int y_, int dx_, int dy_, int height_) : wm(wm_), length(0), listTop(0), listCursor(0), isFocus(false) {
	x = x_;
	y = y_;
	dx = dx_;
	dy = dy_;
	height = height_;
}

void ListBox::append(BPPString& name) {
	data[length++] = name;
}

void ListBox::paint() {
	int i;
	FillRect(wm->display, x, y, dx, dy, MAKE_RGB(255, 255, 255));
	for (i = 0 ; i < 4 ; i++) {
		if (listSelect == listTop + i) {
			FillRect(wm->display, x + 1, y + height * i, dx - 2, height, MAKE_RGB(0, 255, 0));
			DrawText(wm->display, data[listTop + i], x, y + height * i);
		} else {
			DrawText(wm->display, data[listTop + i], x, y + height * i);
		}
	}
	DrawRect(wm->display, x + 1, y + height * listCursor, dx - 2, height, MAKE_RGB(0, 0, 0));
	DrawRect(wm->display, x, y, dx, dy, MAKE_RGB(0, 0, 0));
	wm->update(wm->display);
}

bool ListBox::keyPress(uint16 key) {
	switch(key) {
	case AVK_DOWN:
		if (listCursor < 4 - 1 && listCursor < length - 1) {
			listCursor++;
			paint();
		} else {
			if (listTop < length - 4) {
				listTop++;
				paint();
			}
		}
        return true;
	case AVK_UP:
		if (listCursor > 0) {
			listCursor--;
			paint();
		} else {
			if (listTop > 0) {
				listTop--;
				paint();
			}
		}
		return true;
	case AVK_SELECT:
		listSelect = listTop + listCursor;
		paint();
        return true;
	case AVK_SOFT1:
	    isFocus = false;
		wm->softkeyWindow->setText("", "", "I");
		paint();
		return false;
	}
    return true;
}

void MemoryPanel::load(){
    IFileMgr*  filemgr;
    IFile*  file;
    char  buffer[12];
    int  size;
    ISHELL_CreateInstance(wm->shell, AEECLSID_FILEMGR, (void**)&filemgr);
    file = IFILEMGR_OpenFile(filemgr, CONFIG_FILENAME, _OFM_READ);
    if (file == NULL) {
        size = 0;
    } else {
        size = IFILE_Read(file, buffer, sizeof(buffer) - 1);
        IFILE_Release(file);
        IFILEMGR_Release(filemgr);
    }
    buffer[size] = '\0';
    len = ATOI(buffer);


    data = new LifeGameData*[len + 1];
    for (int i = 0; i < len; i++) {
        data[i] = new LifeGameData(i, wm->shell);
    }
}

void MemoryPanel::save(){
    IFileMgr*  filemgr;
    IFile*  file;
    ISHELL_CreateInstance(wm->shell, AEECLSID_FILEMGR, (void**)&filemgr);
    file = IFILEMGR_OpenFile(filemgr, CONFIG_FILENAME, _OFM_READWRITE);
    if (file == NULL) {
        file = IFILEMGR_OpenFile(filemgr, CONFIG_FILENAME, _OFM_CREATE);
    }
    BPPString lenStr = BPPString::IntToString(len);
    IFILE_Write(file, lenStr.GetBuffer(), lenStr.GetLength());
    IFILE_Release(file);
    IFILEMGR_Release(filemgr);

    for(int i = 0 ; i < len ; i++){
        data[i]->write(i, wm->shell);
    }
}
